@@ -21,3 +21,8 @@ class ElasticUtils(object):
             app.extensions = {}
 
         app.extensions['elasticutils'] = S().es(urls=[app.config['ELASTICSEARCH_URL']])
+
+    def __getattr__(self, item):
+        if not 'elasticutils' in current_app.extensions.keys():
+            raise Exception('not initialised, did you forget to call init_app?')
+        return getattr(current_app.extensions['elasticutils'], item)
